==> ejc-probid-impl-3.0.0-20220715.082857-6-sources.jar: com/ejianc/business/bid/bean/BusinessEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 商机登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probid_bid_business")
public class BusinessEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_name")
    private String projectName; // 招标项目名称
    @TableField(value="construction_unit")
    private String constructionUnit; // 建设单位
    @TableField(value="unitNature_id")
    private Long unitnatureId; // 建设单位 性质
    @TableField(value="unitNature_name")
    private String unitnatureName; // 建设单位 性质(name)
    @TableField(value="unitNature_code")
    private String unitnatureCode; // 建设单位 性质(name)
    @TableField(value="project_scale")
    private String projectScale; // 项目规模
    @TableField(value="investment_volume")
    private BigDecimal investmentVolume; // 投资额
    @TableField(value="civil_erection_cost")
    private BigDecimal civilErectionCost; // 投资额
    @TableField(value="bid_unit_id")
    private Long bidUnitId; // 申请单位
    @TableField(value="bid_unit_name")
    private String bidUnitName; // 申请单位 名称
    @TableField(value="bid_unit_code")
    private String bidUnitCode; // 申请单位 编码
    @TableField(value="implement_model")
    private String implementModel; // 实施模式
    @TableField(value="project_type_id")
    private Long projectTypeId; // 项目类别
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目类别名称
    @TableField(value="project_lever")
    private String projectLever; // 项目跟踪等级
    @TableField(value="project_lever_name")
    private String projectLeverName; // 项目跟踪等级
    @TableField(value="source_project_type")
    private String sourceProjectType; // 项目来源
    @TableField(value="source_project__type_name")
    private String sourceProject_typeName; // 项目来源
    @TableField(value="detailed_address")
    private String detailedAddress; // 详细地址
    @TableField(value="area")
    private String area; // 区域
    @TableField(value="bid_plan_open_date")
    private Date bidPlanOpenDate; // 预计开标日期
    @TableField(value="project_status")
    private String projectStatus; // 项目状态
    @TableField(value="employee_code")
    private String employeeCode; // 项目跟踪人编码
    @TableField(value="employee_name")
    private String employeeName; // 项目跟踪人名称
    @TableField(value="employee_id")
    private Long employeeId; // 项目跟踪人
    @TableField(value="tail_after_situation")
    private String tailAfterSituation; // 项目跟踪情况
    @TableField(value="project_situation")
    private String projectSituation; // 项目概况
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="commit_data")
    private Date commitData; // 提交日期
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名字
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Long getUnitnatureId() {
        return unitnatureId;
    }

    public void setUnitnatureId(Long unitnatureId) {
        this.unitnatureId = unitnatureId;
    }
    public String getUnitnatureName() {
        return unitnatureName;
    }

    public void setUnitnatureName(String unitnatureName) {
        this.unitnatureName = unitnatureName;
    }
    public String getUnitnatureCode() {
        return unitnatureCode;
    }

    public void setUnitnatureCode(String unitnatureCode) {
        this.unitnatureCode = unitnatureCode;
    }
    public String getProjectScale() {
        return projectScale;
    }

    public void setProjectScale(String projectScale) {
        this.projectScale = projectScale;
    }
    public BigDecimal getInvestmentVolume() {
        return investmentVolume;
    }

    public void setInvestmentVolume(BigDecimal investmentVolume) {
        this.investmentVolume = investmentVolume;
    }
    public BigDecimal getCivilErectionCost() {
        return civilErectionCost;
    }

    public void setCivilErectionCost(BigDecimal civilErectionCost) {
        this.civilErectionCost = civilErectionCost;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getImplementModel() {
        return implementModel;
    }

    public void setImplementModel(String implementModel) {
        this.implementModel = implementModel;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProjectLever() {
        return projectLever;
    }

    public void setProjectLever(String projectLever) {
        this.projectLever = projectLever;
    }
    public String getProjectLeverName() {
        return projectLeverName;
    }

    public void setProjectLeverName(String projectLeverName) {
        this.projectLeverName = projectLeverName;
    }
    public String getSourceProjectType() {
        return sourceProjectType;
    }

    public void setSourceProjectType(String sourceProjectType) {
        this.sourceProjectType = sourceProjectType;
    }
    public String getSourceProject_typeName() {
        return sourceProject_typeName;
    }

    public void setSourceProject_typeName(String sourceProject_typeName) {
        this.sourceProject_typeName = sourceProject_typeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public Date getBidPlanOpenDate() {
        return bidPlanOpenDate;
    }

    public void setBidPlanOpenDate(Date bidPlanOpenDate) {
        this.bidPlanOpenDate = bidPlanOpenDate;
    }
    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getTailAfterSituation() {
        return tailAfterSituation;
    }

    public void setTailAfterSituation(String tailAfterSituation) {
        this.tailAfterSituation = tailAfterSituation;
    }
    public String getProjectSituation() {
        return projectSituation;
    }

    public void setProjectSituation(String projectSituation) {
        this.projectSituation = projectSituation;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-probid-impl-3.0.0-20220720.100928-27-sources.jar: com/ejianc/business/bid/bean/BusinessEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 商机登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probid_bid_business")
public class BusinessEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_name")
    private String projectName; // 招标项目名称
    @TableField(value="construction_unit")
    private String constructionUnit; // 建设单位
    @TableField(value="unitNature_id")
    private Long unitnatureId; // 建设单位 性质
    @TableField(value="unitNature_name")
    private String unitnatureName; // 建设单位 性质(name)
    @TableField(value="unitNature_code")
    private String unitnatureCode; // 建设单位 性质(name)
    @TableField(value="project_scale")
    private String projectScale; // 项目规模
    @TableField(value="investment_volume")
    private BigDecimal investmentVolume; // 投资额
    @TableField(value="civil_erection_cost")
    private BigDecimal civilErectionCost; // 投资额
    @TableField(value="bid_unit_id")
    private Long bidUnitId; // 申请单位
    @TableField(value="bid_unit_name")
    private String bidUnitName; // 申请单位 名称
    @TableField(value="bid_unit_code")
    private String bidUnitCode; // 申请单位 编码
    @TableField(value="implement_model")
    private String implementModel; // 实施模式
    @TableField(value="project_type_id")
    private Long projectTypeId; // 项目类别
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目类别名称
    @TableField(value="project_lever")
    private String projectLever; // 项目跟踪等级
    @TableField(value="project_lever_name")
    private String projectLeverName; // 项目跟踪等级
    @TableField(value="source_project_type")
    private Long sourceProjectType; // 项目来源
    @TableField(value="source_project_type_name")
    private String sourceProjectTypeName; // 项目来源
    @TableField(value="detailed_address")
    private String detailedAddress; // 详细地址
    @TableField(value="area")
    private String area; // 区域
    @TableField(value="bid_plan_open_date")
    private Date bidPlanOpenDate; // 预计开标日期
    @TableField(value="project_status")
    private String projectStatus; // 项目状态
    @TableField(value="employee_code")
    private String employeeCode; // 项目跟踪人编码
    @TableField(value="employee_name")
    private String employeeName; // 项目跟踪人名称
    @TableField(value="employee_id")
    private Long employeeId; // 项目跟踪人
    @TableField(value="employee_phone")
    private String employeePhone; // 项目跟踪人电话

    @TableField(value="tail_after_situation")
    private String tailAfterSituation; // 项目跟踪情况
    @TableField(value="project_situation")
    private String projectSituation; // 项目概况
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="commit_data")
    private Date commitData; // 提交日期
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名字
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="ref_flag")
    private Integer refFlag; // 是否被引用

    @TableField(exist = false)
    @SubEntity(serviceName = "busniessRecordService", pidName = "businessId")
    private List<BusinessRecordEntity> recordList = new ArrayList<>();

    public Integer getRefFlag() {
        return refFlag;
    }

    public void setRefFlag(Integer refFlag) {
        this.refFlag = refFlag;
    }

    public List<BusinessRecordEntity> getRecordList() {
        return recordList;
    }

    public void setRecordList(List<BusinessRecordEntity> recordList) {
        this.recordList = recordList;
    }

    public String getEmployeePhone() {
        return employeePhone;
    }

    public void setEmployeePhone(String employeePhone) {
        this.employeePhone = employeePhone;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Long getUnitnatureId() {
        return unitnatureId;
    }

    public void setUnitnatureId(Long unitnatureId) {
        this.unitnatureId = unitnatureId;
    }
    public String getUnitnatureName() {
        return unitnatureName;
    }

    public void setUnitnatureName(String unitnatureName) {
        this.unitnatureName = unitnatureName;
    }
    public String getUnitnatureCode() {
        return unitnatureCode;
    }

    public void setUnitnatureCode(String unitnatureCode) {
        this.unitnatureCode = unitnatureCode;
    }
    public String getProjectScale() {
        return projectScale;
    }

    public void setProjectScale(String projectScale) {
        this.projectScale = projectScale;
    }
    public BigDecimal getInvestmentVolume() {
        return investmentVolume;
    }

    public void setInvestmentVolume(BigDecimal investmentVolume) {
        this.investmentVolume = investmentVolume;
    }
    public BigDecimal getCivilErectionCost() {
        return civilErectionCost;
    }

    public void setCivilErectionCost(BigDecimal civilErectionCost) {
        this.civilErectionCost = civilErectionCost;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getImplementModel() {
        return implementModel;
    }

    public void setImplementModel(String implementModel) {
        this.implementModel = implementModel;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public String getProjectLever() {
        return projectLever;
    }

    public void setProjectLever(String projectLever) {
        this.projectLever = projectLever;
    }
    public String getProjectLeverName() {
        return projectLeverName;
    }

    public void setProjectLeverName(String projectLeverName) {
        this.projectLeverName = projectLeverName;
    }
    public Long getSourceProjectType() {
        return sourceProjectType;
    }

    public void setSourceProjectType(Long sourceProjectType) {
        this.sourceProjectType = sourceProjectType;
    }
    public String getSourceProjectTypeName() {
        return sourceProjectTypeName;
    }

    public void setSourceProjectTypeName(String sourceProjectTypeName) {
        this.sourceProjectTypeName = sourceProjectTypeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public Date getBidPlanOpenDate() {
        return bidPlanOpenDate;
    }

    public void setBidPlanOpenDate(Date bidPlanOpenDate) {
        this.bidPlanOpenDate = bidPlanOpenDate;
    }
    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getTailAfterSituation() {
        return tailAfterSituation;
    }

    public void setTailAfterSituation(String tailAfterSituation) {
        this.tailAfterSituation = tailAfterSituation;
    }
    public String getProjectSituation() {
        return projectSituation;
    }

    public void setProjectSituation(String projectSituation) {
        this.projectSituation = projectSituation;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
